==> antiright-2.99.3.tar.bz2: antiright/gtkshell/option_options.c <==
/*
  AntiRight
  (c) 2002-2006 Jeffrey Bedard
  antiright@gmail.com

  This file is part of AntiRight.

  AntiRight is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  AntiRight is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with AntiRight; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "gtkshell.h"

extern unsigned int gsh_rows;
extern gboolean gsh_button_exits;
extern unsigned int gsh_update_period;

void
gsh_handle_option_arguments(int argc, char **argv, unsigned int *counter)
{
	switch(argv[(*counter)][2])
	{
		case 'e':
			gsh_button_exits=TRUE;
			break;
		case 'g':
			gsh_count(argc, counter);
			gtk_window_parse_geometry(GTK_WINDOW(gsh_window), 
				argv[(*counter)]);
			break;
		case 'n':
			gtk_window_set_decorated(GTK_WINDOW(gsh_window), FALSE);                                             
                	gtk_window_set_skip_taskbar_hint(GTK_WINDOW(gsh_window), TRUE);                                      
                	break;
		case 'r':
			gsh_count(argc, counter);
			gsh_rows=(unsigned int)atoi(argv[(*counter)]);
			break;
		case 'u':
			gsh_count(argc, counter);
			gsh_update_period=atoi(argv[*counter]);
			break;
	}
}

==> antiright-2.99.6.tar.bz2: antiright/gtkshell/option_options.c <==
/*
  AntiRight
  (c) 2002-2006 Jeffrey Bedard
  antiright@gmail.com

  This file is part of AntiRight.

  AntiRight is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  AntiRight is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with AntiRight; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "gtkshell.h"

extern unsigned int gsh_rows;
extern gboolean gsh_button_exits;
extern unsigned int gsh_update_period;
char *gsh_geometry;

void
gsh_handle_option_arguments(int argc, char **argv, unsigned int *counter)
{
	switch(argv[(*counter)][2])
	{
		case 'e':
			gsh_button_exits=TRUE;
			break;
		case 'g':
			gsh_count(argc, counter);
			asprintf(&gsh_geometry, "%s", argv[(*counter)]);
			break;
		case 'n':
			gtk_window_set_decorated(GTK_WINDOW(gsh_window), FALSE);                                             
                	gtk_window_set_skip_taskbar_hint(
				GTK_WINDOW(gsh_window), TRUE);                                      
                	break;
		case 'r':
			gsh_count(argc, counter);
			gsh_rows=(unsigned int)atoi(argv[(*counter)]);
			break;
		case 'u':
			gsh_count(argc, counter);
			gsh_update_period=atoi(argv[*counter]);
			break;
	}
}
